..  Copyright (C)  Brad Miller, David Ranum, Jeffrey Elkner, Peter Wentworth, Allen B. Downey, Chris
    Meyers, and Dario Mitchell.  Permission is granted to copy, distribute
    and/or modify this document under the terms of the GNU Free Documentation
    License, Version 1.3 or any later version published by the Free Software
    Foundation; with Invariant Sections being Forward, Prefaces, and
    Contributor List, no Front-Cover Texts, and no Back-Cover Texts.  A copy of
    the license is included in the section entitled "GNU Free Documentation
    License".

.. qnum::
   :prefix: files-8-
   :start: 1

Glossary
--------

.. glossary::


   open
      You must open a file before you can read its contents.

   close
      When you are done with a file, you should close it.

   read
      Will read the entire contents of a file as a string.  This is often used in an assignment statement
      so that a variable can reference the contents of the file.

   readline
      Will read a single line from the file, up to and including the first instance of the newline character.

   readlines
     Will read the entire contents of a file into a list where each line of the file is a string and is an element in the list.
     
   write
      Will add characters to the end of a file that has been opened for writing.
